pyparsing.pyparsing.ParseSyntaxException

Package pyparsing :: Module pyparsing :: Class ParseSyntaxException |
[hide private]
[frames] | no frames]

# Class ParseSyntaxException

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                  ParseBaseException --+
                                       |
                     ParseFatalException --+
                                           |
                                          ParseSyntaxException

just like ParseFatalException, but thrown internally when an ErrorStop indicates that parsing is to stop immediately because an unbacktrackable syntax error has been found

Instance Methods | [hide private]
__init__(self, pe) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`
Inherited from ParseBaseException
__dir__(self) | source code
__getattr__(self, aname) supported attributes by name are: | source code
__repr__(self) repr(x) | source code
__str__(self) str(x) | source code
markInputline(self, markerString=`'``>!<``'`) Extracts the exception line from the input string, and marks the location of the exception with a special symbol. | source code

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`
Inherited from ParseBaseException
| loc
| msg
| parserElement
| pstr

Method Details | [hide private]

### __init__(self, pe) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)